## Requirements

The tests require:

- the Python package `svglatex`
- [XeLaTeX](https://en.wikipedia.org/wiki/XeTeX)
- [Inkscape](https://en.wikipedia.org/wiki/Inkscape)
- [`svglatex.sty`](https://github.com/johnyf/latex_packages/blob/master/svglatex.sty):
  for convenience, the LaTeX style file `svglatex.sty` is included under the
  directory `tests/`.


## Testing

To run the tests:

```shell
make all
```
